@@ -1,5 +1,5 @@
 from typing import Callable, Self, TypeVar, Generic, ParamSpec
-from functools import wraps
+from functools import update_wrapper
 
 T = TypeVar("T")
 U = TypeVar("U")
@@ -30,9 +30,11 @@ class EagerSuffix(Generic[Params, U]):
         except AttributeError as e:
             ...
 
-        @wraps(func)
+        update_wrapper(self, func)
         def wrapper(*args: Params.args, **kwargs: Params.kwargs) -> U:
             return func(*args, **kwargs)
+        
+        self.__doc__ = self.__doc__ + func.__doc__
 
         self.wrapped = wrapper
 
@@ -67,10 +69,12 @@ class DelayedSuffix(Generic[Params, U]):
         except AttributeError as e:
             ...
 
-        @wraps(func)
+        update_wrapper(self, func)
         def wrapper(*args: Params.args, **kwargs: Params.kwargs) -> U:
             return func(*args, **kwargs)
 
+        self.__doc__ = self.__doc__ + func.__doc__
+
         self.wrapped = wrapper
         self._args = tuple()  # type: ignore
         self._kwargs = dict()  # type: ignore
